@@ -2,7 +2,7 @@
 Enable an AWS Logs integration returns "OK" response
 """
 
-from datadog_api_client.v1 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v1.api.aws_logs_integration_api import AWSLogsIntegrationApi
 from datadog_api_client.v1.model.aws_logs_services_request import AWSLogsServicesRequest
 
