@@ -3,7 +3,7 @@ Update a downtime returns "OK" response
 """
 
 from os import environ
-from datadog_api_client.v1 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v1.api.downtimes_api import DowntimesApi
 from datadog_api_client.v1.model.downtime import Downtime
 
@@ -12,6 +12,7 @@ DOWNTIME_ID = environ["DOWNTIME_ID"]
 
 body = Downtime(
     message="Example-Update_a_downtime_returns_OK_response-updated",
+    mute_first_recovery_notification=True,
 )
 
 configuration = Configuration()
