@@ -4,7 +4,6 @@ Create an API GRPC test returns "OK - Returns the created test details." respons
 
 from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v1.api.synthetics_api import SyntheticsApi
-from datadog_api_client.v1.model.http_method import HTTPMethod
 from datadog_api_client.v1.model.synthetics_api_test import SyntheticsAPITest
 from datadog_api_client.v1.model.synthetics_api_test_config import SyntheticsAPITestConfig
 from datadog_api_client.v1.model.synthetics_api_test_type import SyntheticsAPITestType
@@ -30,7 +29,7 @@ body = SyntheticsAPITest(
             host="localhost",
             port=50051,
             service="Hello",
-            method=HTTPMethod.GET,
+            method="GET",
             message="",
             metadata=SyntheticsTestMetadata(),
         ),
