@@ -4,7 +4,6 @@ Create an API HTTP test returns "OK - Returns the created test details." respons
 
 from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v1.api.synthetics_api import SyntheticsApi
-from datadog_api_client.v1.model.http_method import HTTPMethod
 from datadog_api_client.v1.model.synthetics_api_test import SyntheticsAPITest
 from datadog_api_client.v1.model.synthetics_api_test_config import SyntheticsAPITestConfig
 from datadog_api_client.v1.model.synthetics_api_test_type import SyntheticsAPITestType
@@ -16,6 +15,14 @@ from datadog_api_client.v1.model.synthetics_assertion_json_path_target_target im
 from datadog_api_client.v1.model.synthetics_assertion_operator import SyntheticsAssertionOperator
 from datadog_api_client.v1.model.synthetics_assertion_target import SyntheticsAssertionTarget
 from datadog_api_client.v1.model.synthetics_assertion_type import SyntheticsAssertionType
+from datadog_api_client.v1.model.synthetics_assertion_x_path_operator import SyntheticsAssertionXPathOperator
+from datadog_api_client.v1.model.synthetics_assertion_x_path_target import SyntheticsAssertionXPathTarget
+from datadog_api_client.v1.model.synthetics_assertion_x_path_target_target import SyntheticsAssertionXPathTargetTarget
+from datadog_api_client.v1.model.synthetics_basic_auth_oauth_client import SyntheticsBasicAuthOauthClient
+from datadog_api_client.v1.model.synthetics_basic_auth_oauth_client_type import SyntheticsBasicAuthOauthClientType
+from datadog_api_client.v1.model.synthetics_basic_auth_oauth_token_api_authentication import (
+    SyntheticsBasicAuthOauthTokenApiAuthentication,
+)
 from datadog_api_client.v1.model.synthetics_config_variable import SyntheticsConfigVariable
 from datadog_api_client.v1.model.synthetics_config_variable_type import SyntheticsConfigVariableType
 from datadog_api_client.v1.model.synthetics_test_details_sub_type import SyntheticsTestDetailsSubType
@@ -50,6 +57,15 @@ body = SyntheticsAPITest(
                 ),
                 type=SyntheticsAssertionType.BODY,
             ),
+            SyntheticsAssertionXPathTarget(
+                operator=SyntheticsAssertionXPathOperator.VALIDATES_X_PATH,
+                target=SyntheticsAssertionXPathTargetTarget(
+                    x_path="target-xpath",
+                    target_value="0",
+                    operator="contains",
+                ),
+                type=SyntheticsAssertionType.BODY,
+            ),
         ],
         config_variables=[
             SyntheticsConfigVariable(
@@ -75,13 +91,23 @@ body = SyntheticsAPITest(
             headers=SyntheticsTestHeaders(
                 unique="examplecreateanapihttptestreturnsokreturnsthecreatedtestdetailsresponse",
             ),
-            method=HTTPMethod.GET,
+            method="GET",
             timeout=10.0,
             url="https://datadoghq.com",
             proxy=SyntheticsTestRequestProxy(
                 url="https://datadoghq.com",
                 headers=SyntheticsTestHeaders(),
             ),
+            basic_auth=SyntheticsBasicAuthOauthClient(
+                access_token_url="https://datadog-token.com",
+                audience="audience",
+                client_id="client-id",
+                client_secret="client-secret",
+                resource="resource",
+                scope="yoyo",
+                token_api_authentication=SyntheticsBasicAuthOauthTokenApiAuthentication.HEADER,
+                type=SyntheticsBasicAuthOauthClientType.OAUTH_CLIENT,
+            ),
         ),
     ),
     locations=[
