@@ -3,7 +3,7 @@ Delete an existing incident service returns "OK" response
 """
 
 from os import environ
-from datadog_api_client.v2 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v2.api.incident_services_api import IncidentServicesApi
 
 # there is a valid "service" in the system
