@@ -3,7 +3,7 @@ Get one Application key owned by current user returns "OK" response
 """
 
 from os import environ
-from datadog_api_client.v2 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v2.api.key_management_api import KeyManagementApi
 
 # there is a valid "application_key" in the system
