@@ -17,7 +17,9 @@ body = LogsMetricCreateRequest(
         type=LogsMetricType.LOGS_METRICS,
         attributes=LogsMetricCreateAttributes(
             compute=LogsMetricCompute(
-                aggregation_type=LogsMetricComputeAggregationType.COUNT,
+                aggregation_type=LogsMetricComputeAggregationType.DISTRIBUTION,
+                include_percentiles=True,
+                path="@duration",
             ),
         ),
     ),
