@@ -2,7 +2,7 @@
 List distinct metric volumes by metric name returns "Success" response
 """
 
-from datadog_api_client.v2 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v2.api.metrics_api import MetricsApi
 
 configuration = Configuration()
