@@ -18,7 +18,7 @@ body = RoleCloneRequest(
         attributes=RoleCloneAttributes(
             name="Example-Create_a_new_role_by_cloning_an_existing_role_returns_OK_response clone",
         ),
-        type=RolesType("roles"),
+        type=RolesType.ROLES,
     ),
 )
 
