@@ -473,6 +473,9 @@ class ModelComposed(OpenApiModel):
         self._composed_instances = composed_info[0]
         self._var_name_to_model_instances = composed_info[1]
         self._additional_properties_model_instances = composed_info[2]
+        self._unparsed = any(
+            isinstance(composed_instance, UnparsedObject) for composed_instance in self._composed_instances
+        )
 
     def __setitem__(self, name, value):
         """Set the value of an attribute using square-bracket notation: `instance[attr] = val`."""
@@ -993,10 +996,17 @@ def change_keys_js_to_python(input_dict, model_class):
     may have undeclared properties (additionalProperties attribute in the OAS
     document).
     """
-    if not getattr(model_class, "attribute_map", None):
+    if issubclass(model_class, ModelComposed):
+        attribute_map = {}
+        for t in model_class._composed_schemas.get("oneOf", ()):
+            if issubclass(t, OpenApiModel):
+                attribute_map.update(t.attribute_map)
+    elif not getattr(model_class, "attribute_map", None):
         return input_dict
+    else:
+        attribute_map = model_class.attribute_map
     output_dict = {}
-    reversed_attr_map = {value: key for key, value in model_class.attribute_map.items()}
+    reversed_attr_map = {value: key for key, value in attribute_map.items()}
     for javascript_key, value in input_dict.items():
         python_key = reversed_attr_map.get(javascript_key)
         if python_key is None:
