@@ -1,6 +1,7 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
 
 from datadog_api_client.model_utils import (
@@ -22,7 +23,7 @@ class AWSAccountAndLambdaRequest(ModelNormal):
         "lambda_arn": "lambda_arn",
     }
 
-    def __init__(self_, account_id, lambda_arn, *args, **kwargs):
+    def __init__(self_, account_id: str, lambda_arn: str, **kwargs):
         """
         AWS account ID and Lambda ARN.
 
@@ -34,7 +35,5 @@ class AWSAccountAndLambdaRequest(ModelNormal):
         """
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.account_id = account_id
         self_.lambda_arn = lambda_arn
