@@ -1,14 +1,24 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v1.model.widget_time import WidgetTime
+    from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
+    from datadog_api_client.v1.model.event_timeline_widget_definition_type import EventTimelineWidgetDefinitionType
+
+
 class EventTimelineWidgetDefinition(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -36,7 +46,17 @@ class EventTimelineWidgetDefinition(ModelNormal):
         "type": "type",
     }
 
-    def __init__(self_, query, type, *args, **kwargs):
+    def __init__(
+        self_,
+        query: str,
+        type: EventTimelineWidgetDefinitionType,
+        tags_execution: Union[str, UnsetType] = unset,
+        time: Union[WidgetTime, UnsetType] = unset,
+        title: Union[str, UnsetType] = unset,
+        title_align: Union[WidgetTextAlign, UnsetType] = unset,
+        title_size: Union[str, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         The event timeline is a widget version of the timeline that appears at the top of the Event Stream view. Only available on FREE layout dashboards.
 
@@ -61,9 +81,17 @@ class EventTimelineWidgetDefinition(ModelNormal):
         :param type: Type of the event timeline widget.
         :type type: EventTimelineWidgetDefinitionType
         """
+        if tags_execution is not unset:
+            kwargs["tags_execution"] = tags_execution
+        if time is not unset:
+            kwargs["time"] = time
+        if title is not unset:
+            kwargs["title"] = title
+        if title_align is not unset:
+            kwargs["title_align"] = title_align
+        if title_size is not unset:
+            kwargs["title_size"] = title_size
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.query = query
         self_.type = type
