@@ -1,14 +1,23 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v1.model.formula_and_function_event_aggregation import FormulaAndFunctionEventAggregation
+    from datadog_api_client.v1.model.query_sort_order import QuerySortOrder
+
+
 class FormulaAndFunctionEventQueryGroupBySort(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -29,7 +38,13 @@ class FormulaAndFunctionEventQueryGroupBySort(ModelNormal):
         "order": "order",
     }
 
-    def __init__(self_, aggregation, *args, **kwargs):
+    def __init__(
+        self_,
+        aggregation: FormulaAndFunctionEventAggregation,
+        metric: Union[str, UnsetType] = unset,
+        order: Union[QuerySortOrder, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         Options for sorting group by results.
 
@@ -42,8 +57,10 @@ class FormulaAndFunctionEventQueryGroupBySort(ModelNormal):
         :param order: Direction of sort.
         :type order: QuerySortOrder, optional
         """
+        if metric is not unset:
+            kwargs["metric"] = metric
+        if order is not unset:
+            kwargs["order"] = order
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.aggregation = aggregation
