@@ -1,7 +1,9 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import List, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
@@ -9,6 +11,11 @@ from datadog_api_client.model_utils import (
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v1.model.funnel_source import FunnelSource
+    from datadog_api_client.v1.model.funnel_step import FunnelStep
+
+
 class FunnelQuery(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -27,7 +34,7 @@ class FunnelQuery(ModelNormal):
         "steps": "steps",
     }
 
-    def __init__(self_, data_source, query_string, steps, *args, **kwargs):
+    def __init__(self_, data_source: FunnelSource, query_string: str, steps: List[FunnelStep], **kwargs):
         """
         Updated funnel widget.
 
@@ -42,8 +49,6 @@ class FunnelQuery(ModelNormal):
         """
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.data_source = data_source
         self_.query_string = query_string
         self_.steps = steps
