@@ -1,7 +1,9 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
@@ -9,6 +11,11 @@ from datadog_api_client.model_utils import (
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v1.model.funnel_query import FunnelQuery
+    from datadog_api_client.v1.model.funnel_request_type import FunnelRequestType
+
+
 class FunnelWidgetRequest(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -25,7 +32,7 @@ class FunnelWidgetRequest(ModelNormal):
         "request_type": "request_type",
     }
 
-    def __init__(self_, query, request_type, *args, **kwargs):
+    def __init__(self_, query: FunnelQuery, request_type: FunnelRequestType, **kwargs):
         """
         Updated funnel widget.
 
@@ -37,7 +44,5 @@ class FunnelWidgetRequest(ModelNormal):
         """
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.query = query
         self_.request_type = request_type
