@@ -1,14 +1,28 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import List, Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v1.model.widget_custom_link import WidgetCustomLink
+    from datadog_api_client.v1.model.geomap_widget_request import GeomapWidgetRequest
+    from datadog_api_client.v1.model.geomap_widget_definition_style import GeomapWidgetDefinitionStyle
+    from datadog_api_client.v1.model.widget_time import WidgetTime
+    from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
+    from datadog_api_client.v1.model.geomap_widget_definition_type import GeomapWidgetDefinitionType
+    from datadog_api_client.v1.model.geomap_widget_definition_view import GeomapWidgetDefinitionView
+
+
 class GeomapWidgetDefinition(ModelNormal):
     validations = {
         "requests": {
@@ -51,7 +65,19 @@ class GeomapWidgetDefinition(ModelNormal):
         "view": "view",
     }
 
-    def __init__(self_, requests, style, type, view, *args, **kwargs):
+    def __init__(
+        self_,
+        requests: List[GeomapWidgetRequest],
+        style: GeomapWidgetDefinitionStyle,
+        type: GeomapWidgetDefinitionType,
+        view: GeomapWidgetDefinitionView,
+        custom_links: Union[List[WidgetCustomLink], UnsetType] = unset,
+        time: Union[WidgetTime, UnsetType] = unset,
+        title: Union[str, UnsetType] = unset,
+        title_align: Union[WidgetTextAlign, UnsetType] = unset,
+        title_size: Union[str, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         This visualization displays a series of values by country on a world map.
 
@@ -85,10 +111,18 @@ class GeomapWidgetDefinition(ModelNormal):
         :param view: The view of the world that the map should render.
         :type view: GeomapWidgetDefinitionView
         """
+        if custom_links is not unset:
+            kwargs["custom_links"] = custom_links
+        if time is not unset:
+            kwargs["time"] = time
+        if title is not unset:
+            kwargs["title"] = title
+        if title_align is not unset:
+            kwargs["title_align"] = title_align
+        if title_size is not unset:
+            kwargs["title_size"] = title_size
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.requests = requests
         self_.style = style
         self_.type = type
