@@ -1,14 +1,23 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Dict, List, Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v1.model.host_meta import HostMeta
+    from datadog_api_client.v1.model.host_metrics import HostMetrics
+
+
 class Host(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -49,7 +58,24 @@ class Host(ModelNormal):
         "up": "up",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(
+        self_,
+        aliases: Union[List[str], UnsetType] = unset,
+        apps: Union[List[str], UnsetType] = unset,
+        aws_name: Union[str, UnsetType] = unset,
+        host_name: Union[str, UnsetType] = unset,
+        id: Union[int, UnsetType] = unset,
+        is_muted: Union[bool, UnsetType] = unset,
+        last_reported_time: Union[int, UnsetType] = unset,
+        meta: Union[HostMeta, UnsetType] = unset,
+        metrics: Union[HostMetrics, UnsetType] = unset,
+        mute_timeout: Union[int, UnsetType] = unset,
+        name: Union[str, UnsetType] = unset,
+        sources: Union[List[str], UnsetType] = unset,
+        tags_by_source: Union[Dict[str, List[str]], UnsetType] = unset,
+        up: Union[bool, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         Object representing a host.
 
@@ -95,6 +121,32 @@ class Host(ModelNormal):
         :param up: Displays UP when the expected metrics are received and displays ``???`` if no metrics are received.
         :type up: bool, optional
         """
+        if aliases is not unset:
+            kwargs["aliases"] = aliases
+        if apps is not unset:
+            kwargs["apps"] = apps
+        if aws_name is not unset:
+            kwargs["aws_name"] = aws_name
+        if host_name is not unset:
+            kwargs["host_name"] = host_name
+        if id is not unset:
+            kwargs["id"] = id
+        if is_muted is not unset:
+            kwargs["is_muted"] = is_muted
+        if last_reported_time is not unset:
+            kwargs["last_reported_time"] = last_reported_time
+        if meta is not unset:
+            kwargs["meta"] = meta
+        if metrics is not unset:
+            kwargs["metrics"] = metrics
+        if mute_timeout is not unset:
+            kwargs["mute_timeout"] = mute_timeout
+        if name is not unset:
+            kwargs["name"] = name
+        if sources is not unset:
+            kwargs["sources"] = sources
+        if tags_by_source is not unset:
+            kwargs["tags_by_source"] = tags_by_source
+        if up is not unset:
+            kwargs["up"] = up
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
