@@ -1,14 +1,22 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import List, Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v1.model.host import Host
+
+
 class HostListResponse(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -26,7 +34,13 @@ class HostListResponse(ModelNormal):
         "total_returned": "total_returned",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(
+        self_,
+        host_list: Union[List[Host], UnsetType] = unset,
+        total_matching: Union[int, UnsetType] = unset,
+        total_returned: Union[int, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         Response with Host information from Datadog.
 
@@ -39,6 +53,10 @@ class HostListResponse(ModelNormal):
         :param total_returned: Number of host returned.
         :type total_returned: int, optional
         """
+        if host_list is not unset:
+            kwargs["host_list"] = host_list
+        if total_matching is not unset:
+            kwargs["total_matching"] = total_matching
+        if total_returned is not unset:
+            kwargs["total_returned"] = total_returned
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
