@@ -1,14 +1,23 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v1.model.log_query_definition import LogQueryDefinition
+    from datadog_api_client.v1.model.process_query_definition import ProcessQueryDefinition
+
+
 class HostMapRequest(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -39,7 +48,19 @@ class HostMapRequest(ModelNormal):
         "security_query": "security_query",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(
+        self_,
+        apm_query: Union[LogQueryDefinition, UnsetType] = unset,
+        event_query: Union[LogQueryDefinition, UnsetType] = unset,
+        log_query: Union[LogQueryDefinition, UnsetType] = unset,
+        network_query: Union[LogQueryDefinition, UnsetType] = unset,
+        process_query: Union[ProcessQueryDefinition, UnsetType] = unset,
+        profile_metrics_query: Union[LogQueryDefinition, UnsetType] = unset,
+        q: Union[str, UnsetType] = unset,
+        rum_query: Union[LogQueryDefinition, UnsetType] = unset,
+        security_query: Union[LogQueryDefinition, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         Updated host map.
 
@@ -70,6 +91,22 @@ class HostMapRequest(ModelNormal):
         :param security_query: The log query.
         :type security_query: LogQueryDefinition, optional
         """
+        if apm_query is not unset:
+            kwargs["apm_query"] = apm_query
+        if event_query is not unset:
+            kwargs["event_query"] = event_query
+        if log_query is not unset:
+            kwargs["log_query"] = log_query
+        if network_query is not unset:
+            kwargs["network_query"] = network_query
+        if process_query is not unset:
+            kwargs["process_query"] = process_query
+        if profile_metrics_query is not unset:
+            kwargs["profile_metrics_query"] = profile_metrics_query
+        if q is not unset:
+            kwargs["q"] = q
+        if rum_query is not unset:
+            kwargs["rum_query"] = rum_query
+        if security_query is not unset:
+            kwargs["security_query"] = security_query
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
