@@ -1,14 +1,22 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import List, Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v1.model.list_stream_source import ListStreamSource
+
+
 class ListStreamQuery(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -28,7 +36,14 @@ class ListStreamQuery(ModelNormal):
         "storage": "storage",
     }
 
-    def __init__(self_, data_source, query_string, *args, **kwargs):
+    def __init__(
+        self_,
+        data_source: ListStreamSource,
+        query_string: str,
+        indexes: Union[List[str], UnsetType] = unset,
+        storage: Union[str, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         Updated list stream widget.
 
@@ -44,9 +59,11 @@ class ListStreamQuery(ModelNormal):
         :param storage: Option for storage location. Feature in Private Beta.
         :type storage: str, optional
         """
+        if indexes is not unset:
+            kwargs["indexes"] = indexes
+        if storage is not unset:
+            kwargs["storage"] = storage
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.data_source = data_source
         self_.query_string = query_string
