@@ -1,7 +1,9 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import List
 
 from datadog_api_client.model_utils import (
     ModelNormal,
@@ -20,7 +22,7 @@ class LogsIndexesOrder(ModelNormal):
         "index_names": "index_names",
     }
 
-    def __init__(self_, index_names, *args, **kwargs):
+    def __init__(self_, index_names: List[str], **kwargs):
         """
         Object containing the ordered list of log index names.
 
@@ -31,6 +33,4 @@ class LogsIndexesOrder(ModelNormal):
         """
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.index_names = index_names
