@@ -1,14 +1,22 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import List, Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v1.model.logs_service_remapper_type import LogsServiceRemapperType
+
+
 class LogsServiceRemapper(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -28,7 +36,14 @@ class LogsServiceRemapper(ModelNormal):
         "type": "type",
     }
 
-    def __init__(self_, sources, type, *args, **kwargs):
+    def __init__(
+        self_,
+        sources: List[str],
+        type: LogsServiceRemapperType,
+        is_enabled: Union[bool, UnsetType] = unset,
+        name: Union[str, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         Use this processor if you want to assign one or more attributes as the official service.
 
@@ -47,9 +62,11 @@ class LogsServiceRemapper(ModelNormal):
         :param type: Type of logs service remapper.
         :type type: LogsServiceRemapperType
         """
+        if is_enabled is not unset:
+            kwargs["is_enabled"] = is_enabled
+        if name is not unset:
+            kwargs["name"] = name
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.sources = sources
         self_.type = type
