@@ -1,14 +1,22 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import List, Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v1.model.metrics_query_metadata import MetricsQueryMetadata
+
+
 class MetricsQueryResponse(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -49,7 +57,19 @@ class MetricsQueryResponse(ModelNormal):
         "to_date",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(
+        self_,
+        error: Union[str, UnsetType] = unset,
+        from_date: Union[int, UnsetType] = unset,
+        group_by: Union[List[str], UnsetType] = unset,
+        message: Union[str, UnsetType] = unset,
+        query: Union[str, UnsetType] = unset,
+        res_type: Union[str, UnsetType] = unset,
+        series: Union[List[MetricsQueryMetadata], UnsetType] = unset,
+        status: Union[str, UnsetType] = unset,
+        to_date: Union[int, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         Response Object that includes your query and the list of metrics retrieved.
 
@@ -80,6 +100,22 @@ class MetricsQueryResponse(ModelNormal):
         :param to_date: End of requested time window, milliseconds since Unix epoch.
         :type to_date: int, optional
         """
+        if error is not unset:
+            kwargs["error"] = error
+        if from_date is not unset:
+            kwargs["from_date"] = from_date
+        if group_by is not unset:
+            kwargs["group_by"] = group_by
+        if message is not unset:
+            kwargs["message"] = message
+        if query is not unset:
+            kwargs["query"] = query
+        if res_type is not unset:
+            kwargs["res_type"] = res_type
+        if series is not unset:
+            kwargs["series"] = series
+        if status is not unset:
+            kwargs["status"] = status
+        if to_date is not unset:
+            kwargs["to_date"] = to_date
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
