@@ -1,6 +1,7 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
 
 from datadog_api_client.model_utils import (
@@ -22,7 +23,7 @@ class PagerDutyService(ModelNormal):
         "service_name": "service_name",
     }
 
-    def __init__(self_, service_key, service_name, *args, **kwargs):
+    def __init__(self_, service_key: str, service_name: str, **kwargs):
         """
         The PagerDuty service that is available for integration with Datadog.
 
@@ -34,7 +35,5 @@ class PagerDutyService(ModelNormal):
         """
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.service_key = service_key
         self_.service_name = service_name
