@@ -1,14 +1,23 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v1.model.scatterplot_table_request import ScatterplotTableRequest
+    from datadog_api_client.v1.model.scatter_plot_request import ScatterPlotRequest
+
+
 class ScatterPlotWidgetDefinitionRequests(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -27,7 +36,13 @@ class ScatterPlotWidgetDefinitionRequests(ModelNormal):
         "y": "y",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(
+        self_,
+        table: Union[ScatterplotTableRequest, UnsetType] = unset,
+        x: Union[ScatterPlotRequest, UnsetType] = unset,
+        y: Union[ScatterPlotRequest, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         Widget definition.
 
@@ -40,6 +55,10 @@ class ScatterPlotWidgetDefinitionRequests(ModelNormal):
         :param y: Updated scatter plot.
         :type y: ScatterPlotRequest, optional
         """
+        if table is not unset:
+            kwargs["table"] = table
+        if x is not unset:
+            kwargs["x"] = x
+        if y is not unset:
+            kwargs["y"] = y
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
