@@ -1,12 +1,16 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
     none_type,
+    unset,
+    UnsetType,
 )
 
 
@@ -29,7 +33,15 @@ class SearchSLOResponseLinks(ModelNormal):
         "self": "self",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(
+        self_,
+        first: Union[str, UnsetType] = unset,
+        last: Union[str, none_type, UnsetType] = unset,
+        next: Union[str, UnsetType] = unset,
+        prev: Union[str, none_type, UnsetType] = unset,
+        self: Union[str, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         Pagination links.
 
@@ -48,6 +60,14 @@ class SearchSLOResponseLinks(ModelNormal):
         :param self: Link to current page.
         :type self: str, optional
         """
+        if first is not unset:
+            kwargs["first"] = first
+        if last is not unset:
+            kwargs["last"] = last
+        if next is not unset:
+            kwargs["next"] = next
+        if prev is not unset:
+            kwargs["prev"] = prev
+        if self is not unset:
+            kwargs["self"] = self
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
