@@ -1,14 +1,22 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import List, Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v1.model.service_check_status import ServiceCheckStatus
+
+
 class ServiceCheck(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -32,7 +40,16 @@ class ServiceCheck(ModelNormal):
         "timestamp": "timestamp",
     }
 
-    def __init__(self_, check, host_name, status, tags, *args, **kwargs):
+    def __init__(
+        self_,
+        check: str,
+        host_name: str,
+        status: ServiceCheckStatus,
+        tags: List[str],
+        message: Union[str, UnsetType] = unset,
+        timestamp: Union[int, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         An object containing service check and status.
 
@@ -54,10 +71,12 @@ class ServiceCheck(ModelNormal):
         :param timestamp: Time of check.
         :type timestamp: int, optional
         """
+        if message is not unset:
+            kwargs["message"] = message
+        if timestamp is not unset:
+            kwargs["timestamp"] = timestamp
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.check = check
         self_.host_name = host_name
         self_.status = status
