@@ -1,7 +1,9 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
@@ -9,6 +11,10 @@ from datadog_api_client.model_utils import (
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v1.model.slo_error_timeframe import SLOErrorTimeframe
+
+
 class SLOBulkDeleteError(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -26,7 +32,7 @@ class SLOBulkDeleteError(ModelNormal):
         "timeframe": "timeframe",
     }
 
-    def __init__(self_, id, message, timeframe, *args, **kwargs):
+    def __init__(self_, id: str, message: str, timeframe: SLOErrorTimeframe, **kwargs):
         """
         Object describing the error.
 
@@ -43,8 +49,6 @@ class SLOBulkDeleteError(ModelNormal):
         """
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.id = id
         self_.message = message
         self_.timeframe = timeframe
