@@ -1,14 +1,23 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import List, Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v1.model.slo_bulk_delete_response_data import SLOBulkDeleteResponseData
+    from datadog_api_client.v1.model.slo_bulk_delete_error import SLOBulkDeleteError
+
+
 class SLOBulkDeleteResponse(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -25,7 +34,12 @@ class SLOBulkDeleteResponse(ModelNormal):
         "errors": "errors",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(
+        self_,
+        data: Union[SLOBulkDeleteResponseData, UnsetType] = unset,
+        errors: Union[List[SLOBulkDeleteError], UnsetType] = unset,
+        **kwargs,
+    ):
         """
         The bulk partial delete service level objective object endpoint
         response.
@@ -40,6 +54,8 @@ class SLOBulkDeleteResponse(ModelNormal):
         :param errors: Array of errors object returned.
         :type errors: [SLOBulkDeleteError], optional
         """
+        if data is not unset:
+            kwargs["data"] = data
+        if errors is not unset:
+            kwargs["errors"] = errors
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
