@@ -1,11 +1,15 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import List, Union
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
@@ -22,7 +26,9 @@ class SLOBulkDeleteResponseData(ModelNormal):
         "updated": "updated",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(
+        self_, deleted: Union[List[str], UnsetType] = unset, updated: Union[List[str], UnsetType] = unset, **kwargs
+    ):
         """
         An array of service level objective objects.
 
@@ -35,6 +41,8 @@ class SLOBulkDeleteResponseData(ModelNormal):
             threshold was deleted, but that were not completely deleted).
         :type updated: [str], optional
         """
+        if deleted is not unset:
+            kwargs["deleted"] = deleted
+        if updated is not unset:
+            kwargs["updated"] = updated
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
