@@ -1,14 +1,23 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import List, Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v1.model.slo_correction import SLOCorrection
+    from datadog_api_client.v1.model.response_meta_attributes import ResponseMetaAttributes
+
+
 class SLOCorrectionListResponse(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -25,7 +34,12 @@ class SLOCorrectionListResponse(ModelNormal):
         "meta": "meta",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(
+        self_,
+        data: Union[List[SLOCorrection], UnsetType] = unset,
+        meta: Union[ResponseMetaAttributes, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         A list of  SLO correction objects.
 
@@ -35,6 +49,8 @@ class SLOCorrectionListResponse(ModelNormal):
         :param meta: Object describing meta attributes of response.
         :type meta: ResponseMetaAttributes, optional
         """
+        if data is not unset:
+            kwargs["data"] = data
+        if meta is not unset:
+            kwargs["meta"] = meta
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
