@@ -1,15 +1,27 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
     none_type,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v1.model.slo_correction_category import SLOCorrectionCategory
+    from datadog_api_client.v1.model.creator import Creator
+    from datadog_api_client.v1.model.slo_correction_response_attributes_modifier import (
+        SLOCorrectionResponseAttributesModifier,
+    )
+
+
 class SLOCorrectionResponseAttributes(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -52,7 +64,22 @@ class SLOCorrectionResponseAttributes(ModelNormal):
         "creator",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(
+        self_,
+        category: Union[SLOCorrectionCategory, UnsetType] = unset,
+        created_at: Union[int, UnsetType] = unset,
+        creator: Union[Creator, UnsetType] = unset,
+        description: Union[str, UnsetType] = unset,
+        duration: Union[int, none_type, UnsetType] = unset,
+        end: Union[int, UnsetType] = unset,
+        modified_at: Union[int, UnsetType] = unset,
+        modifier: Union[SLOCorrectionResponseAttributesModifier, none_type, UnsetType] = unset,
+        rrule: Union[str, none_type, UnsetType] = unset,
+        slo_id: Union[str, UnsetType] = unset,
+        start: Union[int, UnsetType] = unset,
+        timezone: Union[str, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         The attribute object associated with the SLO correction.
 
@@ -93,6 +120,28 @@ class SLOCorrectionResponseAttributes(ModelNormal):
         :param timezone: The timezone to display in the UI for the correction times (defaults to "UTC").
         :type timezone: str, optional
         """
+        if category is not unset:
+            kwargs["category"] = category
+        if created_at is not unset:
+            kwargs["created_at"] = created_at
+        if creator is not unset:
+            kwargs["creator"] = creator
+        if description is not unset:
+            kwargs["description"] = description
+        if duration is not unset:
+            kwargs["duration"] = duration
+        if end is not unset:
+            kwargs["end"] = end
+        if modified_at is not unset:
+            kwargs["modified_at"] = modified_at
+        if modifier is not unset:
+            kwargs["modifier"] = modifier
+        if rrule is not unset:
+            kwargs["rrule"] = rrule
+        if slo_id is not unset:
+            kwargs["slo_id"] = slo_id
+        if start is not unset:
+            kwargs["start"] = start
+        if timezone is not unset:
+            kwargs["timezone"] = timezone
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
