@@ -1,7 +1,9 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Any, Dict, Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
@@ -9,9 +11,18 @@ from datadog_api_client.model_utils import (
     date,
     datetime,
     none_type,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v1.model.synthetics_ssl_certificate import SyntheticsSSLCertificate
+    from datadog_api_client.v1.model.synthetics_test_process_status import SyntheticsTestProcessStatus
+    from datadog_api_client.v1.model.synthetics_api_test_result_failure import SyntheticsApiTestResultFailure
+    from datadog_api_client.v1.model.synthetics_timing import SyntheticsTiming
+
+
 class SyntheticsAPITestResultData(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -58,7 +69,19 @@ class SyntheticsAPITestResultData(ModelNormal):
         "timings": "timings",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(
+        self_,
+        cert: Union[SyntheticsSSLCertificate, UnsetType] = unset,
+        event_type: Union[SyntheticsTestProcessStatus, UnsetType] = unset,
+        failure: Union[SyntheticsApiTestResultFailure, UnsetType] = unset,
+        http_status_code: Union[int, UnsetType] = unset,
+        request_headers: Union[Dict[str, dict], UnsetType] = unset,
+        response_body: Union[str, UnsetType] = unset,
+        response_headers: Union[Dict[str, Any], UnsetType] = unset,
+        response_size: Union[int, UnsetType] = unset,
+        timings: Union[SyntheticsTiming, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         Object containing results for your Synthetic API test.
 
@@ -90,6 +113,22 @@ class SyntheticsAPITestResultData(ModelNormal):
             Learn more about those metrics in `Synthetics documentation <https://docs.datadoghq.com/synthetics/#metrics>`_.
         :type timings: SyntheticsTiming, optional
         """
+        if cert is not unset:
+            kwargs["cert"] = cert
+        if event_type is not unset:
+            kwargs["event_type"] = event_type
+        if failure is not unset:
+            kwargs["failure"] = failure
+        if http_status_code is not unset:
+            kwargs["http_status_code"] = http_status_code
+        if request_headers is not unset:
+            kwargs["request_headers"] = request_headers
+        if response_body is not unset:
+            kwargs["response_body"] = response_body
+        if response_headers is not unset:
+            kwargs["response_headers"] = response_headers
+        if response_size is not unset:
+            kwargs["response_size"] = response_size
+        if timings is not unset:
+            kwargs["timings"] = timings
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
