@@ -1,14 +1,22 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v1.model.synthetics_config_variable_type import SyntheticsConfigVariableType
+
+
 class SyntheticsConfigVariable(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -30,7 +38,15 @@ class SyntheticsConfigVariable(ModelNormal):
         "type": "type",
     }
 
-    def __init__(self_, name, type, *args, **kwargs):
+    def __init__(
+        self_,
+        name: str,
+        type: SyntheticsConfigVariableType,
+        example: Union[str, UnsetType] = unset,
+        id: Union[str, UnsetType] = unset,
+        pattern: Union[str, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         Object defining a variable that can be used in your test configuration.
 
@@ -49,9 +65,13 @@ class SyntheticsConfigVariable(ModelNormal):
         :param type: Type of the configuration variable.
         :type type: SyntheticsConfigVariableType
         """
+        if example is not unset:
+            kwargs["example"] = example
+        if id is not unset:
+            kwargs["id"] = id
+        if pattern is not unset:
+            kwargs["pattern"] = pattern
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.name = name
         self_.type = type
