@@ -1,14 +1,22 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import List, Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v1.model.synthetics_deleted_test import SyntheticsDeletedTest
+
+
 class SyntheticsDeleteTestsResponse(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -22,7 +30,7 @@ class SyntheticsDeleteTestsResponse(ModelNormal):
         "deleted_tests": "deleted_tests",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(self_, deleted_tests: Union[List[SyntheticsDeletedTest], UnsetType] = unset, **kwargs):
         """
         Response object for deleting Synthetic tests.
 
@@ -30,6 +38,6 @@ class SyntheticsDeleteTestsResponse(ModelNormal):
             the associated deletion timestamp.
         :type deleted_tests: [SyntheticsDeletedTest], optional
         """
+        if deleted_tests is not unset:
+            kwargs["deleted_tests"] = deleted_tests
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
