@@ -1,7 +1,9 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
@@ -9,6 +11,10 @@ from datadog_api_client.model_utils import (
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v1.model.widget_sort import WidgetSort
+
+
 class WidgetFieldSort(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -24,7 +30,7 @@ class WidgetFieldSort(ModelNormal):
         "order": "order",
     }
 
-    def __init__(self_, column, order, *args, **kwargs):
+    def __init__(self_, column: str, order: WidgetSort, **kwargs):
         """
         Which column and order to sort by
 
@@ -36,7 +42,5 @@ class WidgetFieldSort(ModelNormal):
         """
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.column = column
         self_.order = order
