@@ -352,7 +352,7 @@ class IncidentsApi:
 
         :param include: Specifies which types of related objects should be included in the response.
         :type include: [IncidentRelatedObject], optional
-        :param page_size: Size for a given page.
+        :param page_size: Size for a given page. The maximum allowed value is 5000.
         :type page_size: int, optional
         :param page_offset: Specific offset to use as the beginning of the returned page.
         :type page_offset: int, optional
@@ -383,7 +383,7 @@ class IncidentsApi:
 
         :param include: Specifies which types of related objects should be included in the response.
         :type include: [IncidentRelatedObject], optional
-        :param page_size: Size for a given page.
+        :param page_size: Size for a given page. The maximum allowed value is 5000.
         :type page_size: int, optional
         :param page_offset: Specific offset to use as the beginning of the returned page.
         :type page_offset: int, optional
