@@ -645,7 +645,7 @@ class KeyManagementApi:
 
         List all API keys available for your account.
 
-        :param page_size: Size for a given page.
+        :param page_size: Size for a given page. The maximum allowed value is 5000.
         :type page_size: int, optional
         :param page_number: Specific page number to return.
         :type page_number: int, optional
@@ -711,7 +711,7 @@ class KeyManagementApi:
 
         List all application keys available for your org
 
-        :param page_size: Size for a given page.
+        :param page_size: Size for a given page. The maximum allowed value is 5000.
         :type page_size: int, optional
         :param page_number: Specific page number to return.
         :type page_number: int, optional
@@ -762,7 +762,7 @@ class KeyManagementApi:
 
         List all application keys available for current user
 
-        :param page_size: Size for a given page.
+        :param page_size: Size for a given page. The maximum allowed value is 5000.
         :type page_size: int, optional
         :param page_number: Specific page number to return.
         :type page_number: int, optional
