@@ -170,11 +170,17 @@ class MetricsApi:
                     "location": "query",
                 },
                 "filter_hours_ago": {
+                    "validation": {
+                        "inclusive_maximum": 2147483647,
+                    },
                     "openapi_types": (int,),
                     "attribute": "filter[hours_ago]",
                     "location": "query",
                 },
                 "filter_num_aggregations": {
+                    "validation": {
+                        "inclusive_maximum": 9,
+                    },
                     "openapi_types": (int,),
                     "attribute": "filter[num_aggregations]",
                     "location": "query",
@@ -185,6 +191,9 @@ class MetricsApi:
                     "location": "query",
                 },
                 "filter_timespan_h": {
+                    "validation": {
+                        "inclusive_maximum": 2147483647,
+                    },
                     "openapi_types": (int,),
                     "attribute": "filter[timespan_h]",
                     "location": "query",
@@ -594,7 +603,7 @@ class MetricsApi:
     ) -> MetricsAndMetricTagConfigurationsResponse:
         """Get a list of metrics.
 
-        Returns all metrics (matching additional filters if specified).
+        Returns all metrics that can be configured in the Metrics Summary page or with Metrics without Limits™ (matching additional filters if specified).
 
         :param filter_configured: Filter custom metrics that have configured tags.
         :type filter_configured: bool, optional
