@@ -555,7 +555,7 @@ class RolesApi:
 
         Returns all roles, including their names and their unique identifiers.
 
-        :param page_size: Size for a given page.
+        :param page_size: Size for a given page. The maximum allowed value is 5000.
         :type page_size: int, optional
         :param page_number: Specific page number to return.
         :type page_number: int, optional
@@ -597,7 +597,7 @@ class RolesApi:
 
         :param role_id: The unique identifier of the role.
         :type role_id: str
-        :param page_size: Size for a given page.
+        :param page_size: Size for a given page. The maximum allowed value is 5000.
         :type page_size: int, optional
         :param page_number: Specific page number to return.
         :type page_number: int, optional
