@@ -21,6 +21,13 @@ from datadog_api_client.v2.model.security_filter_update_request import SecurityF
 from datadog_api_client.v2.model.security_monitoring_list_rules_response import SecurityMonitoringListRulesResponse
 from datadog_api_client.v2.model.security_monitoring_rule_response import SecurityMonitoringRuleResponse
 from datadog_api_client.v2.model.security_monitoring_rule_create_payload import SecurityMonitoringRuleCreatePayload
+from datadog_api_client.v2.model.security_monitoring_standard_rule_create_payload import (
+    SecurityMonitoringStandardRuleCreatePayload,
+)
+from datadog_api_client.v2.model.security_monitoring_signal_rule_create_payload import (
+    SecurityMonitoringSignalRuleCreatePayload,
+)
+from datadog_api_client.v2.model.cloud_configuration_rule_create_payload import CloudConfigurationRuleCreatePayload
 from datadog_api_client.v2.model.security_monitoring_rule_update_payload import SecurityMonitoringRuleUpdatePayload
 from datadog_api_client.v2.model.security_monitoring_signals_list_response import SecurityMonitoringSignalsListResponse
 from datadog_api_client.v2.model.security_monitoring_signals_sort import SecurityMonitoringSignalsSort
@@ -494,7 +501,12 @@ class SecurityMonitoringApi:
 
     def create_security_monitoring_rule(
         self,
-        body: SecurityMonitoringRuleCreatePayload,
+        body: Union[
+            SecurityMonitoringRuleCreatePayload,
+            SecurityMonitoringStandardRuleCreatePayload,
+            SecurityMonitoringSignalRuleCreatePayload,
+            CloudConfigurationRuleCreatePayload,
+        ],
     ) -> SecurityMonitoringRuleResponse:
         """Create a detection rule.
 
@@ -684,7 +696,7 @@ class SecurityMonitoringApi:
 
         List rules.
 
-        :param page_size: Size for a given page.
+        :param page_size: Size for a given page. The maximum allowed value is 5000.
         :type page_size: int, optional
         :param page_number: Specific page number to return.
         :type page_number: int, optional
