@@ -287,7 +287,7 @@ class ServiceAccountsApi:
 
         :param service_account_id: The ID of the service account.
         :type service_account_id: str
-        :param page_size: Size for a given page.
+        :param page_size: Size for a given page. The maximum allowed value is 5000.
         :type page_size: int, optional
         :param page_number: Specific page number to return.
         :type page_number: int, optional
