@@ -340,7 +340,8 @@ class UsageMeteringApi:
         """Get estimated cost across your account.
 
         Get estimated cost across multi-org and single root-org accounts.
-        Estimated cost data is only available for the current month and previous month.
+        Estimated cost data is only available for the current month and previous month
+        and is delayed by up to 72 hours from when it was incurred.
         To access historical costs prior to this, use the ``/historical_cost`` endpoint.
 
         :param view: String to specify whether cost is broken down at a parent-org level or at the sub-org level. Available views are ``summary`` and ``sub-org``. Defaults to ``summary``.
@@ -417,7 +418,7 @@ class UsageMeteringApi:
     ) -> HourlyUsageResponse:
         """Get hourly usage by product family.
 
-        Get hourly usage by product family
+        Get hourly usage by product family.
 
         :param filter_timestamp_start: Datetime in ISO-8601 format, UTC, precise to hour: [YYYY-MM-DDThh] for usage beginning at this hour.
         :type filter_timestamp_start: datetime
@@ -426,7 +427,7 @@ class UsageMeteringApi:
             ``infra_hosts`` , ``incident_management`` , ``indexed_logs`` , ``indexed_spans`` , ``ingested_spans`` , ``iot`` ,
             ``lambda_traced_invocations`` , ``logs`` , ``network_flows`` , ``network_hosts`` , ``observability_pipelines`` ,
             ``online_archive`` , ``profiling`` , ``rum`` , ``rum_browser_sessions`` , ``rum_mobile_sessions`` , ``sds`` , ``snmp`` ,
-            ``synthetics_api`` , ``synthetics_browser`` , and ``timeseries``.
+            ``synthetics_api`` , ``synthetics_browser`` , ``synthetics_parallel_testing`` , and ``timeseries``.
         :type filter_product_families: str
         :param filter_timestamp_end: Datetime in ISO-8601 format, UTC, precise to hour: [YYYY-MM-DDThh] for usage ending **before** this hour.
         :type filter_timestamp_end: datetime, optional
