@@ -431,7 +431,7 @@ class UsersApi:
         Get the list of all users in the organization. This list includes
         all users even if they are deactivated or unverified.
 
-        :param page_size: Size for a given page.
+        :param page_size: Size for a given page. The maximum allowed value is 5000.
         :type page_size: int, optional
         :param page_number: Specific page number to return.
         :type page_number: int, optional
