@@ -1,7 +1,9 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
@@ -9,6 +11,13 @@ from datadog_api_client.model_utils import (
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v2.model.cloud_workload_security_agent_rule_update_attributes import (
+        CloudWorkloadSecurityAgentRuleUpdateAttributes,
+    )
+    from datadog_api_client.v2.model.cloud_workload_security_agent_rule_type import CloudWorkloadSecurityAgentRuleType
+
+
 class CloudWorkloadSecurityAgentRuleUpdateData(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -29,7 +38,12 @@ class CloudWorkloadSecurityAgentRuleUpdateData(ModelNormal):
         "type": "type",
     }
 
-    def __init__(self_, attributes, type, *args, **kwargs):
+    def __init__(
+        self_,
+        attributes: CloudWorkloadSecurityAgentRuleUpdateAttributes,
+        type: CloudWorkloadSecurityAgentRuleType,
+        **kwargs,
+    ):
         """
         Object for a single Agent rule.
 
@@ -41,7 +55,5 @@ class CloudWorkloadSecurityAgentRuleUpdateData(ModelNormal):
         """
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.attributes = attributes
         self_.type = type
