@@ -1,11 +1,15 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
@@ -24,7 +28,13 @@ class Creator(ModelNormal):
         "name": "name",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(
+        self_,
+        email: Union[str, UnsetType] = unset,
+        handle: Union[str, UnsetType] = unset,
+        name: Union[str, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         Creator of the object.
 
@@ -37,6 +47,10 @@ class Creator(ModelNormal):
         :param name: Name of the creator.
         :type name: str, optional
         """
+        if email is not unset:
+            kwargs["email"] = email
+        if handle is not unset:
+            kwargs["handle"] = handle
+        if name is not unset:
+            kwargs["name"] = name
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
