@@ -1,15 +1,23 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import List, Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
     datetime,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v2.model.hourly_usage_measurement import HourlyUsageMeasurement
+
+
 class HourlyUsageAttributes(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -33,7 +41,16 @@ class HourlyUsageAttributes(ModelNormal):
         "timestamp": "timestamp",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(
+        self_,
+        measurements: Union[List[HourlyUsageMeasurement], UnsetType] = unset,
+        org_name: Union[str, UnsetType] = unset,
+        product_family: Union[str, UnsetType] = unset,
+        public_id: Union[str, UnsetType] = unset,
+        region: Union[str, UnsetType] = unset,
+        timestamp: Union[datetime, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         Attributes of hourly usage for a product family for an org for a time period.
 
@@ -55,6 +72,16 @@ class HourlyUsageAttributes(ModelNormal):
         :param timestamp: Datetime in ISO-8601 format, UTC. The hour for the usage.
         :type timestamp: datetime, optional
         """
+        if measurements is not unset:
+            kwargs["measurements"] = measurements
+        if org_name is not unset:
+            kwargs["org_name"] = org_name
+        if product_family is not unset:
+            kwargs["product_family"] = product_family
+        if public_id is not unset:
+            kwargs["public_id"] = public_id
+        if region is not unset:
+            kwargs["region"] = region
+        if timestamp is not unset:
+            kwargs["timestamp"] = timestamp
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
