@@ -1,6 +1,7 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
 
 from datadog_api_client.model_utils import (
@@ -22,7 +23,7 @@ class IncidentAttachmentsPostmortemAttributesAttachmentObject(ModelNormal):
         "title": "title",
     }
 
-    def __init__(self_, document_url, title, *args, **kwargs):
+    def __init__(self_, document_url: str, title: str, **kwargs):
         """
         The postmortem attachment.
 
@@ -34,7 +35,5 @@ class IncidentAttachmentsPostmortemAttributesAttachmentObject(ModelNormal):
         """
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.document_url = document_url
         self_.title = title
