@@ -1,14 +1,24 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v2.model.incident_create_attributes import IncidentCreateAttributes
+    from datadog_api_client.v2.model.incident_create_relationships import IncidentCreateRelationships
+    from datadog_api_client.v2.model.incident_type import IncidentType
+
+
 class IncidentCreateData(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -28,7 +38,13 @@ class IncidentCreateData(ModelNormal):
         "type": "type",
     }
 
-    def __init__(self_, attributes, type, *args, **kwargs):
+    def __init__(
+        self_,
+        attributes: IncidentCreateAttributes,
+        type: IncidentType,
+        relationships: Union[IncidentCreateRelationships, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         Incident data for a create request.
 
@@ -41,9 +57,9 @@ class IncidentCreateData(ModelNormal):
         :param type: Incident resource type.
         :type type: IncidentType
         """
+        if relationships is not unset:
+            kwargs["relationships"] = relationships
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.attributes = attributes
         self_.type = type
