@@ -1,11 +1,15 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
@@ -24,7 +28,13 @@ class IncidentResponseMetaPagination(ModelNormal):
         "size": "size",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(
+        self_,
+        next_offset: Union[int, UnsetType] = unset,
+        offset: Union[int, UnsetType] = unset,
+        size: Union[int, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         Pagination properties.
 
@@ -37,6 +47,10 @@ class IncidentResponseMetaPagination(ModelNormal):
         :param size: Maximum size of pages to return.
         :type size: int, optional
         """
+        if next_offset is not unset:
+            kwargs["next_offset"] = next_offset
+        if offset is not unset:
+            kwargs["offset"] = offset
+        if size is not unset:
+            kwargs["size"] = size
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
