@@ -1,14 +1,24 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v2.model.incident_team_response_attributes import IncidentTeamResponseAttributes
+    from datadog_api_client.v2.model.incident_team_relationships import IncidentTeamRelationships
+    from datadog_api_client.v2.model.incident_team_type import IncidentTeamType
+
+
 class IncidentTeamResponseData(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -33,7 +43,14 @@ class IncidentTeamResponseData(ModelNormal):
         "relationships",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(
+        self_,
+        attributes: Union[IncidentTeamResponseAttributes, UnsetType] = unset,
+        id: Union[str, UnsetType] = unset,
+        relationships: Union[IncidentTeamRelationships, UnsetType] = unset,
+        type: Union[IncidentTeamType, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         Incident Team data from a response.
 
@@ -49,6 +66,12 @@ class IncidentTeamResponseData(ModelNormal):
         :param type: Incident Team resource type.
         :type type: IncidentTeamType, optional
         """
+        if attributes is not unset:
+            kwargs["attributes"] = attributes
+        if id is not unset:
+            kwargs["id"] = id
+        if relationships is not unset:
+            kwargs["relationships"] = relationships
+        if type is not unset:
+            kwargs["type"] = type
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
