@@ -1,14 +1,26 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v2.model.nullable_relationship_to_user import NullableRelationshipToUser
+    from datadog_api_client.v2.model.relationship_to_incident_integration_metadatas import (
+        RelationshipToIncidentIntegrationMetadatas,
+    )
+    from datadog_api_client.v2.model.relationship_to_incident_postmortem import RelationshipToIncidentPostmortem
+
+
 class IncidentUpdateRelationships(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -30,7 +42,13 @@ class IncidentUpdateRelationships(ModelNormal):
         "postmortem": "postmortem",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(
+        self_,
+        commander_user: Union[NullableRelationshipToUser, UnsetType] = unset,
+        integrations: Union[RelationshipToIncidentIntegrationMetadatas, UnsetType] = unset,
+        postmortem: Union[RelationshipToIncidentPostmortem, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         The incident's relationships for an update request.
 
@@ -43,6 +61,10 @@ class IncidentUpdateRelationships(ModelNormal):
         :param postmortem: A relationship reference for postmortems.
         :type postmortem: RelationshipToIncidentPostmortem, optional
         """
+        if commander_user is not unset:
+            kwargs["commander_user"] = commander_user
+        if integrations is not unset:
+            kwargs["integrations"] = integrations
+        if postmortem is not unset:
+            kwargs["postmortem"] = postmortem
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
