@@ -1,14 +1,23 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Dict, Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v2.model.logs_aggregate_bucket_value import LogsAggregateBucketValue
+    from datadog_api_client.v2.model.logs_aggregate_bucket_value_timeseries import LogsAggregateBucketValueTimeseries
+
+
 class LogsAggregateBucket(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -24,7 +33,14 @@ class LogsAggregateBucket(ModelNormal):
         "computes": "computes",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(
+        self_,
+        by: Union[Dict[str, str], UnsetType] = unset,
+        computes: Union[
+            Dict[str, Union[LogsAggregateBucketValue, str, float, LogsAggregateBucketValueTimeseries]], UnsetType
+        ] = unset,
+        **kwargs,
+    ):
         """
         A bucket values
 
@@ -34,6 +50,8 @@ class LogsAggregateBucket(ModelNormal):
         :param computes: A map of the metric name -> value for regular compute or list of values for a timeseries
         :type computes: {str: (LogsAggregateBucketValue,)}, optional
         """
+        if by is not unset:
+            kwargs["by"] = by
+        if computes is not unset:
+            kwargs["computes"] = computes
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
