@@ -1,7 +1,9 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import List
 
 from datadog_api_client.model_utils import (
     ModelNormal,
@@ -20,7 +22,7 @@ class LogsArchiveOrderAttributes(ModelNormal):
         "archive_ids": "archive_ids",
     }
 
-    def __init__(self_, archive_ids, *args, **kwargs):
+    def __init__(self_, archive_ids: List[str], **kwargs):
         """
         The attributes associated with the archive order.
 
@@ -30,6 +32,4 @@ class LogsArchiveOrderAttributes(ModelNormal):
         """
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.archive_ids = archive_ids
