@@ -1,14 +1,25 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v2.model.logs_group_by_histogram import LogsGroupByHistogram
+    from datadog_api_client.v2.model.logs_group_by_missing import LogsGroupByMissing
+    from datadog_api_client.v2.model.logs_aggregate_sort import LogsAggregateSort
+    from datadog_api_client.v2.model.logs_group_by_total import LogsGroupByTotal
+
+
 class LogsGroupBy(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -35,7 +46,16 @@ class LogsGroupBy(ModelNormal):
         "total": "total",
     }
 
-    def __init__(self_, facet, *args, **kwargs):
+    def __init__(
+        self_,
+        facet: str,
+        histogram: Union[LogsGroupByHistogram, UnsetType] = unset,
+        limit: Union[int, UnsetType] = unset,
+        missing: Union[LogsGroupByMissing, str, float, UnsetType] = unset,
+        sort: Union[LogsAggregateSort, UnsetType] = unset,
+        total: Union[LogsGroupByTotal, bool, str, float, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         A group by rule
 
@@ -58,8 +78,16 @@ class LogsGroupBy(ModelNormal):
         :param total: A resulting object to put the given computes in over all the matching records.
         :type total: LogsGroupByTotal, optional
         """
+        if histogram is not unset:
+            kwargs["histogram"] = histogram
+        if limit is not unset:
+            kwargs["limit"] = limit
+        if missing is not unset:
+            kwargs["missing"] = missing
+        if sort is not unset:
+            kwargs["sort"] = sort
+        if total is not unset:
+            kwargs["total"] = total
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.facet = facet
