@@ -1,14 +1,23 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v2.model.metric_bulk_tag_config_create_attributes import MetricBulkTagConfigCreateAttributes
+    from datadog_api_client.v2.model.metric_bulk_configure_tags_type import MetricBulkConfigureTagsType
+
+
 class MetricBulkTagConfigCreate(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -29,7 +38,13 @@ class MetricBulkTagConfigCreate(ModelNormal):
         "type": "type",
     }
 
-    def __init__(self_, id, type, *args, **kwargs):
+    def __init__(
+        self_,
+        id: str,
+        type: MetricBulkConfigureTagsType,
+        attributes: Union[MetricBulkTagConfigCreateAttributes, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         Request object to bulk configure tags for metrics matching the given prefix.
 
@@ -42,9 +57,9 @@ class MetricBulkTagConfigCreate(ModelNormal):
         :param type: The metric bulk configure tags resource.
         :type type: MetricBulkConfigureTagsType
         """
+        if attributes is not unset:
+            kwargs["attributes"] = attributes
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.id = id
         self_.type = type
