@@ -1,7 +1,9 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
@@ -9,6 +11,11 @@ from datadog_api_client.model_utils import (
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v2.model.metric_custom_space_aggregation import MetricCustomSpaceAggregation
+    from datadog_api_client.v2.model.metric_custom_time_aggregation import MetricCustomTimeAggregation
+
+
 class MetricCustomAggregation(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -25,7 +32,7 @@ class MetricCustomAggregation(ModelNormal):
         "time": "time",
     }
 
-    def __init__(self_, space, time, *args, **kwargs):
+    def __init__(self_, space: MetricCustomSpaceAggregation, time: MetricCustomTimeAggregation, **kwargs):
         """
         A time and space aggregation combination for use in query.
 
@@ -37,7 +44,5 @@ class MetricCustomAggregation(ModelNormal):
         """
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.space = space
         self_.time = time
