@@ -1,7 +1,9 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import List, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
@@ -9,6 +11,10 @@ from datadog_api_client.model_utils import (
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v2.model.metric_series import MetricSeries
+
+
 class MetricPayload(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -22,7 +28,7 @@ class MetricPayload(ModelNormal):
         "series": "series",
     }
 
-    def __init__(self_, series, *args, **kwargs):
+    def __init__(self_, series: List[MetricSeries], **kwargs):
         """
         The metrics' payload.
 
@@ -31,6 +37,4 @@ class MetricPayload(ModelNormal):
         """
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.series = series
