@@ -1,14 +1,25 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v2.model.metric_tag_configuration_update_attributes import (
+        MetricTagConfigurationUpdateAttributes,
+    )
+    from datadog_api_client.v2.model.metric_tag_configuration_type import MetricTagConfigurationType
+
+
 class MetricTagConfigurationUpdateData(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -29,7 +40,13 @@ class MetricTagConfigurationUpdateData(ModelNormal):
         "type": "type",
     }
 
-    def __init__(self_, id, type, *args, **kwargs):
+    def __init__(
+        self_,
+        id: str,
+        type: MetricTagConfigurationType,
+        attributes: Union[MetricTagConfigurationUpdateAttributes, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         Object for a single tag configuration to be edited.
 
@@ -42,9 +59,9 @@ class MetricTagConfigurationUpdateData(ModelNormal):
         :param type: The metric tag configuration resource type.
         :type type: MetricTagConfigurationType
         """
+        if attributes is not unset:
+            kwargs["attributes"] = attributes
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.id = id
         self_.type = type
