@@ -1,7 +1,9 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
@@ -9,6 +11,10 @@ from datadog_api_client.model_utils import (
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v2.model.incident_attachment_type import IncidentAttachmentType
+
+
 class RelationshipToIncidentAttachmentData(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -24,7 +30,7 @@ class RelationshipToIncidentAttachmentData(ModelNormal):
         "type": "type",
     }
 
-    def __init__(self_, id, type, *args, **kwargs):
+    def __init__(self_, id: str, type: IncidentAttachmentType, **kwargs):
         """
         The attachment relationship data.
 
@@ -36,7 +42,5 @@ class RelationshipToIncidentAttachmentData(ModelNormal):
         """
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.id = id
         self_.type = type
