@@ -1,22 +1,34 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
 class RUMApplicationAttributes(ModelNormal):
+    validations = {
+        "org_id": {
+            "inclusive_maximum": 2147483647,
+        },
+    }
+
     @cached_property
     def openapi_types(_):
         return {
             "application_id": (str,),
+            "client_token": (str,),
             "created_at": (int,),
             "created_by_handle": (str,),
             "hash": (str,),
+            "is_active": (bool,),
             "name": (str,),
             "org_id": (int,),
             "type": (str,),
@@ -26,9 +38,11 @@ class RUMApplicationAttributes(ModelNormal):
 
     attribute_map = {
         "application_id": "application_id",
+        "client_token": "client_token",
         "created_at": "created_at",
         "created_by_handle": "created_by_handle",
         "hash": "hash",
+        "is_active": "is_active",
         "name": "name",
         "org_id": "org_id",
         "type": "type",
@@ -38,16 +52,18 @@ class RUMApplicationAttributes(ModelNormal):
 
     def __init__(
         self_,
-        application_id,
-        created_at,
-        created_by_handle,
-        name,
-        org_id,
-        type,
-        updated_at,
-        updated_by_handle,
-        *args,
-        **kwargs
+        application_id: str,
+        client_token: str,
+        created_at: int,
+        created_by_handle: str,
+        name: str,
+        org_id: int,
+        type: str,
+        updated_at: int,
+        updated_by_handle: str,
+        hash: Union[str, UnsetType] = unset,
+        is_active: Union[bool, UnsetType] = unset,
+        **kwargs,
     ):
         """
         RUM application attributes.
@@ -55,15 +71,21 @@ class RUMApplicationAttributes(ModelNormal):
         :param application_id: ID of the RUM application.
         :type application_id: str
 
+        :param client_token: Client token of the RUM application.
+        :type client_token: str
+
         :param created_at: Timestamp in ms of the creation date.
         :type created_at: int
 
         :param created_by_handle: Handle of the creator user.
         :type created_by_handle: str
 
-        :param hash: Client token of the RUM application.
+        :param hash: Hash of the RUM application. Optional.
         :type hash: str, optional
 
+        :param is_active: Indicates if the RUM application is active.
+        :type is_active: bool, optional
+
         :param name: Name of the RUM application.
         :type name: str
 
@@ -79,11 +101,14 @@ class RUMApplicationAttributes(ModelNormal):
         :param updated_by_handle: Handle of the updater user.
         :type updated_by_handle: str
         """
+        if hash is not unset:
+            kwargs["hash"] = hash
+        if is_active is not unset:
+            kwargs["is_active"] = is_active
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.application_id = application_id
+        self_.client_token = client_token
         self_.created_at = created_at
         self_.created_by_handle = created_by_handle
         self_.name = name
