@@ -1,7 +1,9 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
@@ -9,6 +11,11 @@ from datadog_api_client.model_utils import (
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v2.model.rum_application_create_attributes import RUMApplicationCreateAttributes
+    from datadog_api_client.v2.model.rum_application_create_type import RUMApplicationCreateType
+
+
 class RUMApplicationCreate(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -25,7 +32,7 @@ class RUMApplicationCreate(ModelNormal):
         "type": "type",
     }
 
-    def __init__(self_, attributes, type, *args, **kwargs):
+    def __init__(self_, attributes: RUMApplicationCreateAttributes, type: RUMApplicationCreateType, **kwargs):
         """
         RUM application creation.
 
@@ -37,7 +44,5 @@ class RUMApplicationCreate(ModelNormal):
         """
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.attributes = attributes
         self_.type = type
