@@ -1,11 +1,15 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
@@ -24,7 +28,13 @@ class RUMWarning(ModelNormal):
         "title": "title",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(
+        self_,
+        code: Union[str, UnsetType] = unset,
+        detail: Union[str, UnsetType] = unset,
+        title: Union[str, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         A warning message indicating something that went wrong with the query.
 
@@ -37,6 +47,10 @@ class RUMWarning(ModelNormal):
         :param title: A short human-readable summary of the warning.
         :type title: str, optional
         """
+        if code is not unset:
+            kwargs["code"] = code
+        if detail is not unset:
+            kwargs["detail"] = detail
+        if title is not unset:
+            kwargs["title"] = title
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
