@@ -1,6 +1,7 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
 
 from datadog_api_client.model_utils import (
@@ -22,7 +23,7 @@ class SecurityFilterExclusionFilter(ModelNormal):
         "query": "query",
     }
 
-    def __init__(self_, name, query, *args, **kwargs):
+    def __init__(self_, name: str, query: str, **kwargs):
         """
         Exclusion filter for the security filter.
 
@@ -34,7 +35,5 @@ class SecurityFilterExclusionFilter(ModelNormal):
         """
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.name = name
         self_.query = query
