@@ -1,6 +1,7 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
 
 from datadog_api_client.model_utils import (
@@ -10,7 +11,7 @@ from datadog_api_client.model_utils import (
 
 
 class SecurityMonitoringRuleCreatePayload(ModelComposed):
-    def __init__(self_, *args, **kwargs):
+    def __init__(self, **kwargs):
         """
         Create a new rule.
 
@@ -43,11 +44,12 @@ class SecurityMonitoringRuleCreatePayload(ModelComposed):
 
         :param type: The rule type.
         :type type: SecurityMonitoringRuleTypeCreate, optional
+
+        :param compliance_signal_options: How to generate compliance signals. Useful for cloud_configuration rules only.
+        :type compliance_signal_options: CloudConfigurationRuleComplianceSignalOptions
         """
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
     @cached_property
     def _composed_schemas(_):
         # we need this here to make our import statements work
@@ -63,10 +65,14 @@ class SecurityMonitoringRuleCreatePayload(ModelComposed):
         from datadog_api_client.v2.model.security_monitoring_signal_rule_create_payload import (
             SecurityMonitoringSignalRuleCreatePayload,
         )
+        from datadog_api_client.v2.model.cloud_configuration_rule_create_payload import (
+            CloudConfigurationRuleCreatePayload,
+        )
 
         return {
             "oneOf": [
                 SecurityMonitoringStandardRuleCreatePayload,
                 SecurityMonitoringSignalRuleCreatePayload,
+                CloudConfigurationRuleCreatePayload,
             ],
         }
