@@ -1,6 +1,7 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
 
 from datadog_api_client.model_utils import (
@@ -10,13 +11,16 @@ from datadog_api_client.model_utils import (
 
 
 class SecurityMonitoringRuleResponse(ModelComposed):
-    def __init__(self_, *args, **kwargs):
+    def __init__(self, **kwargs):
         """
         Create a new rule.
 
         :param cases: Cases for generating signals.
         :type cases: [SecurityMonitoringRuleCase], optional
 
+        :param compliance_signal_options: How to generate compliance signals. Useful for cloud_configuration rules only.
+        :type compliance_signal_options: CloudConfigurationRuleComplianceSignalOptions, optional
+
         :param created_at: When the rule was created, timestamp in milliseconds.
         :type created_at: int, optional
 
@@ -67,8 +71,6 @@ class SecurityMonitoringRuleResponse(ModelComposed):
         """
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
     @cached_property
     def _composed_schemas(_):
         # we need this here to make our import statements work
