@@ -1,7 +1,9 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
@@ -9,6 +11,12 @@ from datadog_api_client.model_utils import (
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v2.model.security_monitoring_signal_incidents_update_attributes import (
+        SecurityMonitoringSignalIncidentsUpdateAttributes,
+    )
+
+
 class SecurityMonitoringSignalIncidentsUpdateData(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -24,7 +32,7 @@ class SecurityMonitoringSignalIncidentsUpdateData(ModelNormal):
         "attributes": "attributes",
     }
 
-    def __init__(self_, attributes, *args, **kwargs):
+    def __init__(self_, attributes: SecurityMonitoringSignalIncidentsUpdateAttributes, **kwargs):
         """
         Data containing the patch for changing the related incidents of a signal.
 
@@ -33,6 +41,4 @@ class SecurityMonitoringSignalIncidentsUpdateData(ModelNormal):
         """
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.attributes = attributes
