@@ -1,11 +1,15 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
@@ -20,7 +24,7 @@ class SecurityMonitoringSignalsListResponseLinks(ModelNormal):
         "next": "next",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(self_, next: Union[str, UnsetType] = unset, **kwargs):
         """
         Links attributes.
 
@@ -28,6 +32,6 @@ class SecurityMonitoringSignalsListResponseLinks(ModelNormal):
             POST endpoint.
         :type next: str, optional
         """
+        if next is not unset:
+            kwargs["next"] = next
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
