@@ -1,14 +1,24 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v2.model.user_create_attributes import UserCreateAttributes
+    from datadog_api_client.v2.model.user_relationships import UserRelationships
+    from datadog_api_client.v2.model.users_type import UsersType
+
+
 class UserCreateData(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -28,7 +38,13 @@ class UserCreateData(ModelNormal):
         "type": "type",
     }
 
-    def __init__(self_, attributes, type, *args, **kwargs):
+    def __init__(
+        self_,
+        attributes: UserCreateAttributes,
+        type: UsersType,
+        relationships: Union[UserRelationships, UnsetType] = unset,
+        **kwargs,
+    ):
         """
         Object to create a user.
 
@@ -41,9 +57,9 @@ class UserCreateData(ModelNormal):
         :param type: Users resource type.
         :type type: UsersType
         """
+        if relationships is not unset:
+            kwargs["relationships"] = relationships
         super().__init__(kwargs)
 
-        self_._check_pos_args(args)
-
         self_.attributes = attributes
         self_.type = type
