@@ -1,14 +1,26 @@
 # Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 # This product includes software developed at Datadog (https://www.datadoghq.com/).
 # Copyright 2019-Present Datadog, Inc.
+from __future__ import annotations
 
+from typing import List, Union, TYPE_CHECKING
 
 from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    unset,
+    UnsetType,
 )
 
 
+if TYPE_CHECKING:
+    from datadog_api_client.v2.model.user import User
+    from datadog_api_client.v2.model.user_response_included_item import UserResponseIncludedItem
+    from datadog_api_client.v2.model.organization import Organization
+    from datadog_api_client.v2.model.permission import Permission
+    from datadog_api_client.v2.model.role import Role
+
+
 class UserResponse(ModelNormal):
     @cached_property
     def openapi_types(_):
@@ -25,7 +37,12 @@ class UserResponse(ModelNormal):
         "included": "included",
     }
 
-    def __init__(self_, *args, **kwargs):
+    def __init__(
+        self_,
+        data: Union[User, UnsetType] = unset,
+        included: Union[List[Union[UserResponseIncludedItem, Organization, Permission, Role]], UnsetType] = unset,
+        **kwargs,
+    ):
         """
         Response containing information about a single user.
 
@@ -35,6 +52,8 @@ class UserResponse(ModelNormal):
         :param included: Array of objects related to the user.
         :type included: [UserResponseIncludedItem], optional
         """
+        if data is not unset:
+            kwargs["data"] = data
+        if included is not unset:
+            kwargs["included"] = included
         super().__init__(kwargs)
-
-        self_._check_pos_args(args)
