@@ -52,7 +52,66 @@ from datadog_api_client.v2.model.authn_mapping_update_request import AuthNMappin
 from datadog_api_client.v2.model.authn_mappings_response import AuthNMappingsResponse
 from datadog_api_client.v2.model.authn_mappings_sort import AuthNMappingsSort
 from datadog_api_client.v2.model.authn_mappings_type import AuthNMappingsType
+from datadog_api_client.v2.model.ci_app_aggregate_bucket_value import CIAppAggregateBucketValue
+from datadog_api_client.v2.model.ci_app_aggregate_bucket_value_timeseries import CIAppAggregateBucketValueTimeseries
+from datadog_api_client.v2.model.ci_app_aggregate_bucket_value_timeseries_point import (
+    CIAppAggregateBucketValueTimeseriesPoint,
+)
+from datadog_api_client.v2.model.ci_app_aggregate_sort import CIAppAggregateSort
+from datadog_api_client.v2.model.ci_app_aggregate_sort_type import CIAppAggregateSortType
+from datadog_api_client.v2.model.ci_app_aggregation_function import CIAppAggregationFunction
+from datadog_api_client.v2.model.ci_app_compute import CIAppCompute
+from datadog_api_client.v2.model.ci_app_compute_type import CIAppComputeType
+from datadog_api_client.v2.model.ci_app_computes import CIAppComputes
+from datadog_api_client.v2.model.ci_app_event_attributes import CIAppEventAttributes
+from datadog_api_client.v2.model.ci_app_group_by_histogram import CIAppGroupByHistogram
+from datadog_api_client.v2.model.ci_app_group_by_missing import CIAppGroupByMissing
+from datadog_api_client.v2.model.ci_app_group_by_total import CIAppGroupByTotal
+from datadog_api_client.v2.model.ci_app_pipeline_event import CIAppPipelineEvent
+from datadog_api_client.v2.model.ci_app_pipeline_event_type_name import CIAppPipelineEventTypeName
+from datadog_api_client.v2.model.ci_app_pipeline_events_request import CIAppPipelineEventsRequest
+from datadog_api_client.v2.model.ci_app_pipeline_events_response import CIAppPipelineEventsResponse
+from datadog_api_client.v2.model.ci_app_pipelines_aggregate_request import CIAppPipelinesAggregateRequest
+from datadog_api_client.v2.model.ci_app_pipelines_aggregation_buckets_response import (
+    CIAppPipelinesAggregationBucketsResponse,
+)
+from datadog_api_client.v2.model.ci_app_pipelines_analytics_aggregate_response import (
+    CIAppPipelinesAnalyticsAggregateResponse,
+)
+from datadog_api_client.v2.model.ci_app_pipelines_bucket_response import CIAppPipelinesBucketResponse
+from datadog_api_client.v2.model.ci_app_pipelines_group_by import CIAppPipelinesGroupBy
+from datadog_api_client.v2.model.ci_app_pipelines_query_filter import CIAppPipelinesQueryFilter
+from datadog_api_client.v2.model.ci_app_query_options import CIAppQueryOptions
+from datadog_api_client.v2.model.ci_app_query_page_options import CIAppQueryPageOptions
+from datadog_api_client.v2.model.ci_app_response_links import CIAppResponseLinks
+from datadog_api_client.v2.model.ci_app_response_metadata import CIAppResponseMetadata
+from datadog_api_client.v2.model.ci_app_response_page import CIAppResponsePage
+from datadog_api_client.v2.model.ci_app_response_status import CIAppResponseStatus
+from datadog_api_client.v2.model.ci_app_sort import CIAppSort
+from datadog_api_client.v2.model.ci_app_sort_order import CIAppSortOrder
+from datadog_api_client.v2.model.ci_app_test_event import CIAppTestEvent
+from datadog_api_client.v2.model.ci_app_test_event_type_name import CIAppTestEventTypeName
+from datadog_api_client.v2.model.ci_app_test_events_request import CIAppTestEventsRequest
+from datadog_api_client.v2.model.ci_app_test_events_response import CIAppTestEventsResponse
+from datadog_api_client.v2.model.ci_app_tests_aggregate_request import CIAppTestsAggregateRequest
+from datadog_api_client.v2.model.ci_app_tests_aggregation_buckets_response import CIAppTestsAggregationBucketsResponse
+from datadog_api_client.v2.model.ci_app_tests_analytics_aggregate_response import CIAppTestsAnalyticsAggregateResponse
+from datadog_api_client.v2.model.ci_app_tests_bucket_response import CIAppTestsBucketResponse
+from datadog_api_client.v2.model.ci_app_tests_group_by import CIAppTestsGroupBy
+from datadog_api_client.v2.model.ci_app_tests_query_filter import CIAppTestsQueryFilter
+from datadog_api_client.v2.model.ci_app_warning import CIAppWarning
 from datadog_api_client.v2.model.chargeback_breakdown import ChargebackBreakdown
+from datadog_api_client.v2.model.cloud_configuration_compliance_rule_options import (
+    CloudConfigurationComplianceRuleOptions,
+)
+from datadog_api_client.v2.model.cloud_configuration_rego_rule import CloudConfigurationRegoRule
+from datadog_api_client.v2.model.cloud_configuration_rule_case_create import CloudConfigurationRuleCaseCreate
+from datadog_api_client.v2.model.cloud_configuration_rule_compliance_signal_options import (
+    CloudConfigurationRuleComplianceSignalOptions,
+)
+from datadog_api_client.v2.model.cloud_configuration_rule_create_payload import CloudConfigurationRuleCreatePayload
+from datadog_api_client.v2.model.cloud_configuration_rule_options import CloudConfigurationRuleOptions
+from datadog_api_client.v2.model.cloud_configuration_rule_type import CloudConfigurationRuleType
 from datadog_api_client.v2.model.cloud_workload_security_agent_rule_attributes import (
     CloudWorkloadSecurityAgentRuleAttributes,
 )
@@ -88,6 +147,30 @@ from datadog_api_client.v2.model.cloud_workload_security_agent_rule_updater_attr
 from datadog_api_client.v2.model.cloud_workload_security_agent_rules_list_response import (
     CloudWorkloadSecurityAgentRulesListResponse,
 )
+from datadog_api_client.v2.model.confluent_account_create_request import ConfluentAccountCreateRequest
+from datadog_api_client.v2.model.confluent_account_create_request_attributes import (
+    ConfluentAccountCreateRequestAttributes,
+)
+from datadog_api_client.v2.model.confluent_account_create_request_data import ConfluentAccountCreateRequestData
+from datadog_api_client.v2.model.confluent_account_resource_attributes import ConfluentAccountResourceAttributes
+from datadog_api_client.v2.model.confluent_account_response import ConfluentAccountResponse
+from datadog_api_client.v2.model.confluent_account_response_attributes import ConfluentAccountResponseAttributes
+from datadog_api_client.v2.model.confluent_account_response_data import ConfluentAccountResponseData
+from datadog_api_client.v2.model.confluent_account_type import ConfluentAccountType
+from datadog_api_client.v2.model.confluent_account_update_request import ConfluentAccountUpdateRequest
+from datadog_api_client.v2.model.confluent_account_update_request_attributes import (
+    ConfluentAccountUpdateRequestAttributes,
+)
+from datadog_api_client.v2.model.confluent_account_update_request_data import ConfluentAccountUpdateRequestData
+from datadog_api_client.v2.model.confluent_accounts_response import ConfluentAccountsResponse
+from datadog_api_client.v2.model.confluent_resource_request import ConfluentResourceRequest
+from datadog_api_client.v2.model.confluent_resource_request_attributes import ConfluentResourceRequestAttributes
+from datadog_api_client.v2.model.confluent_resource_request_data import ConfluentResourceRequestData
+from datadog_api_client.v2.model.confluent_resource_response import ConfluentResourceResponse
+from datadog_api_client.v2.model.confluent_resource_response_attributes import ConfluentResourceResponseAttributes
+from datadog_api_client.v2.model.confluent_resource_response_data import ConfluentResourceResponseData
+from datadog_api_client.v2.model.confluent_resource_type import ConfluentResourceType
+from datadog_api_client.v2.model.confluent_resources_response import ConfluentResourcesResponse
 from datadog_api_client.v2.model.content_encoding import ContentEncoding
 from datadog_api_client.v2.model.cost_by_org import CostByOrg
 from datadog_api_client.v2.model.cost_by_org_attributes import CostByOrgAttributes
@@ -298,6 +381,7 @@ from datadog_api_client.v2.model.logs_metric_response_filter import LogsMetricRe
 from datadog_api_client.v2.model.logs_metric_response_group_by import LogsMetricResponseGroupBy
 from datadog_api_client.v2.model.logs_metric_type import LogsMetricType
 from datadog_api_client.v2.model.logs_metric_update_attributes import LogsMetricUpdateAttributes
+from datadog_api_client.v2.model.logs_metric_update_compute import LogsMetricUpdateCompute
 from datadog_api_client.v2.model.logs_metric_update_data import LogsMetricUpdateData
 from datadog_api_client.v2.model.logs_metric_update_request import LogsMetricUpdateRequest
 from datadog_api_client.v2.model.logs_metrics_response import LogsMetricsResponse
@@ -307,6 +391,7 @@ from datadog_api_client.v2.model.logs_response_metadata import LogsResponseMetad
 from datadog_api_client.v2.model.logs_response_metadata_page import LogsResponseMetadataPage
 from datadog_api_client.v2.model.logs_sort import LogsSort
 from datadog_api_client.v2.model.logs_sort_order import LogsSortOrder
+from datadog_api_client.v2.model.logs_storage_tier import LogsStorageTier
 from datadog_api_client.v2.model.logs_warning import LogsWarning
 from datadog_api_client.v2.model.metric import Metric
 from datadog_api_client.v2.model.metric_active_configuration_type import MetricActiveConfigurationType
@@ -428,6 +513,9 @@ from datadog_api_client.v2.model.rum_application_create import RUMApplicationCre
 from datadog_api_client.v2.model.rum_application_create_attributes import RUMApplicationCreateAttributes
 from datadog_api_client.v2.model.rum_application_create_request import RUMApplicationCreateRequest
 from datadog_api_client.v2.model.rum_application_create_type import RUMApplicationCreateType
+from datadog_api_client.v2.model.rum_application_list import RUMApplicationList
+from datadog_api_client.v2.model.rum_application_list_attributes import RUMApplicationListAttributes
+from datadog_api_client.v2.model.rum_application_list_type import RUMApplicationListType
 from datadog_api_client.v2.model.rum_application_response import RUMApplicationResponse
 from datadog_api_client.v2.model.rum_application_type import RUMApplicationType
 from datadog_api_client.v2.model.rum_application_update import RUMApplicationUpdate
@@ -600,6 +688,9 @@ from datadog_api_client.v2.model.security_monitoring_signal_rule_create_payload
 )
 from datadog_api_client.v2.model.security_monitoring_signal_rule_query import SecurityMonitoringSignalRuleQuery
 from datadog_api_client.v2.model.security_monitoring_signal_rule_response import SecurityMonitoringSignalRuleResponse
+from datadog_api_client.v2.model.security_monitoring_signal_rule_response_query import (
+    SecurityMonitoringSignalRuleResponseQuery,
+)
 from datadog_api_client.v2.model.security_monitoring_signal_rule_type import SecurityMonitoringSignalRuleType
 from datadog_api_client.v2.model.security_monitoring_signal_state import SecurityMonitoringSignalState
 from datadog_api_client.v2.model.security_monitoring_signal_state_update_attributes import (
@@ -640,9 +731,140 @@ from datadog_api_client.v2.model.security_monitoring_standard_rule_response impo
     SecurityMonitoringStandardRuleResponse,
 )
 from datadog_api_client.v2.model.security_monitoring_triage_user import SecurityMonitoringTriageUser
+from datadog_api_client.v2.model.sensitive_data_scanner_config_request import SensitiveDataScannerConfigRequest
+from datadog_api_client.v2.model.sensitive_data_scanner_configuration import SensitiveDataScannerConfiguration
+from datadog_api_client.v2.model.sensitive_data_scanner_configuration_data import SensitiveDataScannerConfigurationData
+from datadog_api_client.v2.model.sensitive_data_scanner_configuration_relationships import (
+    SensitiveDataScannerConfigurationRelationships,
+)
+from datadog_api_client.v2.model.sensitive_data_scanner_configuration_type import SensitiveDataScannerConfigurationType
+from datadog_api_client.v2.model.sensitive_data_scanner_create_group_response import (
+    SensitiveDataScannerCreateGroupResponse,
+)
+from datadog_api_client.v2.model.sensitive_data_scanner_create_rule_response import (
+    SensitiveDataScannerCreateRuleResponse,
+)
+from datadog_api_client.v2.model.sensitive_data_scanner_filter import SensitiveDataScannerFilter
+from datadog_api_client.v2.model.sensitive_data_scanner_get_config_included_array import (
+    SensitiveDataScannerGetConfigIncludedArray,
+)
+from datadog_api_client.v2.model.sensitive_data_scanner_get_config_included_item import (
+    SensitiveDataScannerGetConfigIncludedItem,
+)
+from datadog_api_client.v2.model.sensitive_data_scanner_get_config_response import SensitiveDataScannerGetConfigResponse
+from datadog_api_client.v2.model.sensitive_data_scanner_get_config_response_data import (
+    SensitiveDataScannerGetConfigResponseData,
+)
+from datadog_api_client.v2.model.sensitive_data_scanner_group import SensitiveDataScannerGroup
+from datadog_api_client.v2.model.sensitive_data_scanner_group_attributes import SensitiveDataScannerGroupAttributes
+from datadog_api_client.v2.model.sensitive_data_scanner_group_create import SensitiveDataScannerGroupCreate
+from datadog_api_client.v2.model.sensitive_data_scanner_group_create_request import (
+    SensitiveDataScannerGroupCreateRequest,
+)
+from datadog_api_client.v2.model.sensitive_data_scanner_group_data import SensitiveDataScannerGroupData
+from datadog_api_client.v2.model.sensitive_data_scanner_group_delete_request import (
+    SensitiveDataScannerGroupDeleteRequest,
+)
+from datadog_api_client.v2.model.sensitive_data_scanner_group_delete_response import (
+    SensitiveDataScannerGroupDeleteResponse,
+)
+from datadog_api_client.v2.model.sensitive_data_scanner_group_included_item import SensitiveDataScannerGroupIncludedItem
+from datadog_api_client.v2.model.sensitive_data_scanner_group_item import SensitiveDataScannerGroupItem
+from datadog_api_client.v2.model.sensitive_data_scanner_group_list import SensitiveDataScannerGroupList
+from datadog_api_client.v2.model.sensitive_data_scanner_group_relationships import (
+    SensitiveDataScannerGroupRelationships,
+)
+from datadog_api_client.v2.model.sensitive_data_scanner_group_response import SensitiveDataScannerGroupResponse
+from datadog_api_client.v2.model.sensitive_data_scanner_group_type import SensitiveDataScannerGroupType
+from datadog_api_client.v2.model.sensitive_data_scanner_group_update import SensitiveDataScannerGroupUpdate
+from datadog_api_client.v2.model.sensitive_data_scanner_group_update_request import (
+    SensitiveDataScannerGroupUpdateRequest,
+)
+from datadog_api_client.v2.model.sensitive_data_scanner_group_update_response import (
+    SensitiveDataScannerGroupUpdateResponse,
+)
+from datadog_api_client.v2.model.sensitive_data_scanner_meta import SensitiveDataScannerMeta
+from datadog_api_client.v2.model.sensitive_data_scanner_meta_version_only import SensitiveDataScannerMetaVersionOnly
+from datadog_api_client.v2.model.sensitive_data_scanner_product import SensitiveDataScannerProduct
+from datadog_api_client.v2.model.sensitive_data_scanner_reorder_config import SensitiveDataScannerReorderConfig
+from datadog_api_client.v2.model.sensitive_data_scanner_reorder_groups_response import (
+    SensitiveDataScannerReorderGroupsResponse,
+)
+from datadog_api_client.v2.model.sensitive_data_scanner_rule import SensitiveDataScannerRule
+from datadog_api_client.v2.model.sensitive_data_scanner_rule_attributes import SensitiveDataScannerRuleAttributes
+from datadog_api_client.v2.model.sensitive_data_scanner_rule_create import SensitiveDataScannerRuleCreate
+from datadog_api_client.v2.model.sensitive_data_scanner_rule_create_request import SensitiveDataScannerRuleCreateRequest
+from datadog_api_client.v2.model.sensitive_data_scanner_rule_data import SensitiveDataScannerRuleData
+from datadog_api_client.v2.model.sensitive_data_scanner_rule_delete_request import SensitiveDataScannerRuleDeleteRequest
+from datadog_api_client.v2.model.sensitive_data_scanner_rule_delete_response import (
+    SensitiveDataScannerRuleDeleteResponse,
+)
+from datadog_api_client.v2.model.sensitive_data_scanner_rule_included_item import SensitiveDataScannerRuleIncludedItem
+from datadog_api_client.v2.model.sensitive_data_scanner_rule_relationships import SensitiveDataScannerRuleRelationships
+from datadog_api_client.v2.model.sensitive_data_scanner_rule_response import SensitiveDataScannerRuleResponse
+from datadog_api_client.v2.model.sensitive_data_scanner_rule_type import SensitiveDataScannerRuleType
+from datadog_api_client.v2.model.sensitive_data_scanner_rule_update import SensitiveDataScannerRuleUpdate
+from datadog_api_client.v2.model.sensitive_data_scanner_rule_update_request import SensitiveDataScannerRuleUpdateRequest
+from datadog_api_client.v2.model.sensitive_data_scanner_rule_update_response import (
+    SensitiveDataScannerRuleUpdateResponse,
+)
+from datadog_api_client.v2.model.sensitive_data_scanner_standard_pattern import SensitiveDataScannerStandardPattern
+from datadog_api_client.v2.model.sensitive_data_scanner_standard_pattern_attributes import (
+    SensitiveDataScannerStandardPatternAttributes,
+)
+from datadog_api_client.v2.model.sensitive_data_scanner_standard_pattern_data import (
+    SensitiveDataScannerStandardPatternData,
+)
+from datadog_api_client.v2.model.sensitive_data_scanner_standard_pattern_type import (
+    SensitiveDataScannerStandardPatternType,
+)
+from datadog_api_client.v2.model.sensitive_data_scanner_standard_patterns_response import (
+    SensitiveDataScannerStandardPatternsResponse,
+)
+from datadog_api_client.v2.model.sensitive_data_scanner_standard_patterns_response_data import (
+    SensitiveDataScannerStandardPatternsResponseData,
+)
+from datadog_api_client.v2.model.sensitive_data_scanner_standard_patterns_response_item import (
+    SensitiveDataScannerStandardPatternsResponseItem,
+)
+from datadog_api_client.v2.model.sensitive_data_scanner_text_replacement import SensitiveDataScannerTextReplacement
+from datadog_api_client.v2.model.sensitive_data_scanner_text_replacement_type import (
+    SensitiveDataScannerTextReplacementType,
+)
 from datadog_api_client.v2.model.service_account_create_attributes import ServiceAccountCreateAttributes
 from datadog_api_client.v2.model.service_account_create_data import ServiceAccountCreateData
 from datadog_api_client.v2.model.service_account_create_request import ServiceAccountCreateRequest
+from datadog_api_client.v2.model.service_definition_create_response import ServiceDefinitionCreateResponse
+from datadog_api_client.v2.model.service_definition_data import ServiceDefinitionData
+from datadog_api_client.v2.model.service_definition_data_attributes import ServiceDefinitionDataAttributes
+from datadog_api_client.v2.model.service_definition_get_response import ServiceDefinitionGetResponse
+from datadog_api_client.v2.model.service_definition_meta import ServiceDefinitionMeta
+from datadog_api_client.v2.model.service_definition_schema import ServiceDefinitionSchema
+from datadog_api_client.v2.model.service_definition_v1 import ServiceDefinitionV1
+from datadog_api_client.v2.model.service_definition_v1_contact import ServiceDefinitionV1Contact
+from datadog_api_client.v2.model.service_definition_v1_info import ServiceDefinitionV1Info
+from datadog_api_client.v2.model.service_definition_v1_integrations import ServiceDefinitionV1Integrations
+from datadog_api_client.v2.model.service_definition_v1_org import ServiceDefinitionV1Org
+from datadog_api_client.v2.model.service_definition_v1_resource import ServiceDefinitionV1Resource
+from datadog_api_client.v2.model.service_definition_v1_resource_type import ServiceDefinitionV1ResourceType
+from datadog_api_client.v2.model.service_definition_v1_version import ServiceDefinitionV1Version
+from datadog_api_client.v2.model.service_definition_v2 import ServiceDefinitionV2
+from datadog_api_client.v2.model.service_definition_v2_contact import ServiceDefinitionV2Contact
+from datadog_api_client.v2.model.service_definition_v2_doc import ServiceDefinitionV2Doc
+from datadog_api_client.v2.model.service_definition_v2_email import ServiceDefinitionV2Email
+from datadog_api_client.v2.model.service_definition_v2_email_type import ServiceDefinitionV2EmailType
+from datadog_api_client.v2.model.service_definition_v2_integrations import ServiceDefinitionV2Integrations
+from datadog_api_client.v2.model.service_definition_v2_link import ServiceDefinitionV2Link
+from datadog_api_client.v2.model.service_definition_v2_link_type import ServiceDefinitionV2LinkType
+from datadog_api_client.v2.model.service_definition_v2_opsgenie import ServiceDefinitionV2Opsgenie
+from datadog_api_client.v2.model.service_definition_v2_opsgenie_region import ServiceDefinitionV2OpsgenieRegion
+from datadog_api_client.v2.model.service_definition_v2_repo import ServiceDefinitionV2Repo
+from datadog_api_client.v2.model.service_definition_v2_slack import ServiceDefinitionV2Slack
+from datadog_api_client.v2.model.service_definition_v2_slack_type import ServiceDefinitionV2SlackType
+from datadog_api_client.v2.model.service_definition_v2_version import ServiceDefinitionV2Version
+from datadog_api_client.v2.model.service_definitions_create_request import ServiceDefinitionsCreateRequest
+from datadog_api_client.v2.model.service_definitions_list_response import ServiceDefinitionsListResponse
+from datadog_api_client.v2.model.tags_event_attribute import TagsEventAttribute
 from datadog_api_client.v2.model.usage_application_security_monitoring_response import (
     UsageApplicationSecurityMonitoringResponse,
 )
